﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Windows.Forms;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.DataPreprocessing.Views {

  [View("Transformation View")]
  [Content(typeof(TransformationContent), true)]
  public partial class TransformationView : AsynchronousContentView {

    public TransformationView() {
      InitializeComponent();
    }

    public new TransformationContent Content {
      get { return (TransformationContent)base.Content; }
      set { base.Content = value; }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        transformationCollectionView.Content = null;
      } else {
        transformationCollectionView.Content = Content.CheckedTransformationCollection;
      }
    }

    private void applyButton_Click(object sender, EventArgs e) {
      var transformations = Content.CheckedTransformationCollection.CheckedItems;

      var transformator = new PreprocessingTransformator(Content.Data);
      string errorMsg;
      bool success = transformator.ApplyTransformations(transformations, out errorMsg);
      if (success) {
        Content.CheckedTransformationCollection.Clear();
        MessageBox.Show(this, "Transformations applied.", "Success", MessageBoxButtons.OK, MessageBoxIcon.Information);
      } else {
        MessageBox.Show(this,
          "Error in Transformation.\nValue is copied when transformion of cell failed.\n" + errorMsg,
          "Transformation failed", MessageBoxButtons.OK, MessageBoxIcon.Warning);
      }

    }
  }
}
